@@ -1,16 +1,13 @@
 #
 # (c) Ferenc Erki <erkiferenc@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Cloud::OpenStack;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.4'; # VERSION
+our $VERSION = '1.14.2'; # VERSION
 
 use Rex::Logger;
 
@@ -25,7 +22,7 @@ BEGIN {
 use Data::Dumper;
 use Carp;
 use MIME::Base64 qw(decode_base64);
-use Digest::MD5 qw(md5_hex);
+use Digest::MD5  qw(md5_hex);
 use File::Basename;
 
 sub new {
