@@ -1,8 +1,6 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 =head1 NAME
 
@@ -15,7 +13,7 @@ With this Module you can manage your cronjobs.
 =head1 SYNOPSIS
 
  use Rex::Commands::Cron;
- 
+
  cron add => "root", {
         minute => '5',
         hour  => '*',
@@ -24,9 +22,9 @@ With this Module you can manage your cronjobs.
         day_of_week => '*',
         command => '/path/to/your/cronjob',
       };
- 
+
  cron list => "root";
- 
+
  cron delete => "root", 3;
 
 =head1 EXPORTED FUNCTIONS
@@ -35,11 +33,10 @@ With this Module you can manage your cronjobs.
 
 package Rex::Commands::Cron;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.2'; # VERSION
+our $VERSION = '1.14.2'; # VERSION
 
 require Rex::Exporter;
 use base qw(Rex::Exporter);
@@ -65,7 +62,7 @@ Manage cron entries.
    day_of_month => "1,3,5",
    user         => "root",
    on_change    => sub { say "cron added"; };
- 
+
  # remove an entry
  cron_entry "reload-httpd",
    ensure       => "absent",
@@ -163,7 +160,7 @@ List cronjobs.
 
  use Rex::Commands::Cron;
  use Data::Dumper;
- 
+
  task "listcron", "server1", sub {
    my @crons = cron list => "root";
    print Dumper(\@crons);
@@ -175,7 +172,7 @@ This example will add a cronjob running on minute 1, 5, 19 and 40. Every hour an
 
  use Rex::Commands::Cron;
  use Data::Dumper;
- 
+
  task "addcron", "server1", sub {
     cron add => "root", {
       minute => "1,5,19,40",
@@ -210,10 +207,10 @@ Managing Environment Variables inside cron.
     cron env => user => add => {
       MYVAR => "foo",
     };
- 
+
     cron env => user => delete => $index;
     cron env => user => delete => 1;
- 
+
     cron env => user => "list";
  };
 
@@ -234,9 +231,9 @@ sub cron {
     if ( $c->add( %{$config} ) ) {
       my $rnd_file = $c->write_cron;
       $c->activate_user_cron( $rnd_file, $user );
-      return 1;              # something changed
+      return 1; # something changed
     }
-    return 0;                # nothing changed
+    return 0;   # nothing changed
   }
 
   elsif ( $action eq "delete" ) {
