@@ -1,8 +1,6 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 =head1 NAME
 
@@ -25,11 +23,10 @@ All these functions will not be reported. These functions don't modify anything.
 
 package Rex::Commands::Gather;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.2'; # VERSION
+our $VERSION = '1.14.2'; # VERSION
 
 use Data::Dumper;
 use Rex::Hardware;
