@@ -18,10 +18,9 @@ With this module you can create filesystems on existing partitions and logical v
 package Rex::Commands::Mkfs;
 
 use warnings;
-use 5.010001;
-use strict;
+use v5.12.5;
 
-our $VERSION = '1.13.2'; # VERSION
+our $VERSION = '1.14.2'; # VERSION
 
 require Rex::Exporter;
 use base qw(Rex::Exporter);
