@@ -1,8 +1,6 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 =head1 NAME
 
@@ -48,11 +46,10 @@ This module can sync directories between your Rex system and your servers withou
 
 package Rex::Commands::Sync;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.4'; # VERSION
+our $VERSION = '1.14.2'; # VERSION
 
 require Rex::Exporter;
 use base qw(Rex::Exporter);
