@@ -1,8 +1,6 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 =head1 NAME
 
@@ -23,11 +21,10 @@ With this module you can define host groups in an INI style file.
 
 package Rex::Group::Lookup::INI;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.2'; # VERSION
+our $VERSION = '1.14.2'; # VERSION
 
 use Rex -base;
 
@@ -49,7 +46,7 @@ File example:
  [webservers]
  fe01
  fe02
-    
+
  [backends]
  be[01..03]
 
