@@ -1,17 +1,14 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Interface::Shell::Tcsh;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 use Rex::Interface::Shell::Csh;
 
-our $VERSION = '1.13.2'; # VERSION
+our $VERSION = '1.14.2'; # VERSION
 
 use base qw(Rex::Interface::Shell::Csh);
 
