@@ -1,16 +1,13 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Inventory::DMIDecode::Section;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.2'; # VERSION
+our $VERSION = '1.14.2'; # VERSION
 
 require Exporter;
 use Symbol;
@@ -140,4 +137,3 @@ sub get_index {
 }
 
 1;
-
