@@ -4,11 +4,10 @@
 
 package Rex::Pkg::ALT;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.2'; # VERSION
+our $VERSION = '1.14.2'; # VERSION
 
 use Rex::Helper::Run;
 use Rex::Commands::File;
