@@ -1,19 +1,16 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Pkg::Base;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 use Rex::Helper::Run;
 use Rex::Interface::Exec;
 use Net::OpenSSH::ShellQuoter;
 
-our $VERSION = '1.13.4'; # VERSION
+our $VERSION = '1.14.2'; # VERSION
 
 sub new {
   my $that  = shift;
@@ -273,7 +270,9 @@ OLD_PKG:
   push @modifications, map { $_->{action} = 'installed'; $_ }
     grep { !exists $_->{found} } @new_installed;
 
-  map { delete $_->{found} } @modifications;
+  for (@modifications) {
+    delete $_->{found};
+  }
 
   return @modifications;
 }
