@@ -1,15 +1,13 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Profiler;
 
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.12.0'; # VERSION
+our $VERSION = '1.14.2'; # VERSION
 
 use Time::HiRes qw(gettimeofday tv_interval);
 
