@@ -1,8 +1,6 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 =head1 NAME
 
@@ -27,15 +25,15 @@ Currently nesting data structures works only if the assignment is made on the to
    use Rex::Shared::Var;
    share qw(%hash %nested);
  }
- 
+
  # this doesn't work as expected
  $hash{key} = { nested_key => 42 };
  $hash{key}->{nested_key} = -1; # $hash{key}->{nested_key} still returns 42
- 
+
  # workaround 1 - top level assignments
  $hash{key} = { nested_key => 42 };
  $hash{key} = { nested_key => -1 };
- 
+
  # workaround 2 - nesting shared variables
  $nested{nested_key}      = 42;
  $hash{key}               = \%nested;
@@ -47,10 +45,12 @@ Currently nesting data structures works only if the assignment is made on the to
 
 package Rex::Shared::Var;
 
-use strict qw(vars subs);
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.4'; # VERSION
+our $VERSION = '1.14.2'; # VERSION
+
+use Symbol;
 
 require Exporter;
 use base qw(Exporter);
@@ -81,26 +81,27 @@ sub share {
   my @vars = @_;
   my ( $package, $file, $line ) = caller;
 
-  my ( $sigil, $sym );
+  my ( $sigil, $symbol );
   for my $var (@vars) {
 
-    if ( ( $sigil, $sym ) = ( $var =~ /^([\$\@\%\*\&])(.+)/ ) ) {
-      $sym = "${package}::$sym";
+    if ( ( $sigil, $symbol ) = ( $var =~ /^([\$\@\%\*\&])(.+)/ ) ) {
+      my $ref_to_symbol = qualify_to_ref $symbol, $package;
+      $symbol = "${package}::$symbol";
 
       if ( $sigil eq "\$" ) {
         eval "use Rex::Shared::Var::Scalar;";
-        tie $$sym, "Rex::Shared::Var::Scalar", $sym;
-        *$sym = \$$sym;
+        tie ${ *{$ref_to_symbol} }, "Rex::Shared::Var::Scalar", $symbol;
+        *{$ref_to_symbol} = \${ *{$ref_to_symbol} };
       }
       elsif ( $sigil eq "\@" ) {
         eval "use Rex::Shared::Var::Array;";
-        tie @$sym, "Rex::Shared::Var::Array", $sym;
-        *$sym = \@$sym;
+        tie @{ *{$ref_to_symbol} }, "Rex::Shared::Var::Array", $symbol;
+        *{$ref_to_symbol} = \@{ *{$ref_to_symbol} };
       }
       elsif ( $sigil eq "\%" ) {
         eval "use Rex::Shared::Var::Hash;";
-        tie %$sym, "Rex::Shared::Var::Hash", $sym;
-        *$sym = \%$sym;
+        tie %{ *{$ref_to_symbol} }, "Rex::Shared::Var::Hash", $symbol;
+        *{$ref_to_symbol} = \%{ *{$ref_to_symbol} };
       }
     }
 
