@@ -1,20 +1,17 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Shared::Var::Common;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
 require Exporter;
 use base qw/Exporter/;
 our @EXPORT_OK = qw/__lock __store __retrieve/;
 
-our $VERSION = '1.13.2'; # VERSION
+our $VERSION = '1.14.2'; # VERSION
 
 use Fcntl qw(:DEFAULT :flock);
 use Storable;
