@@ -1,8 +1,6 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 =head1 NAME
 
@@ -15,33 +13,33 @@ With this module you can manage VirtualBox.
 =head1 SYNOPSIS
 
  use Rex::Commands::Virtualization;
-   
+
  set virtualization => "VBox";
-   
- use Data::Dumper;  
-  
+
+ use Data::Dumper;
+
  print Dumper vm list => "all";
  print Dumper vm list => "running";
-   
+
  vm destroy => "vm01";
-   
- vm delete => "vm01"; 
-    
+
+ vm delete => "vm01";
+
  vm start => "vm01";
-   
+
  vm shutdown => "vm01";
-   
+
  vm reboot => "vm01";
-   
+
  vm option => "vm01",
        memory    => 512;
-          
+
  print Dumper vm info => "vm01";
-   
- # creating a vm 
+
+ # creating a vm
  vm create => "vm01",
     storage    => [
-      {  
+      {
         file  => "/mnt/data/vbox/vm01.img",
         size  => "10G",
       },
@@ -50,18 +48,18 @@ With this module you can manage VirtualBox.
       }
     ],
     memory => 512,
-    type => "Linux26", 
+    type => "Linux26",
     cpus => 1,
     boot => "dvd";
-  
+
  vm forward_port => "vm01", add => { http => [8080, 80] };
-  
+
  vm forward_port => "vm01", remove => "http";
-  
+
  print Dumper vm guestinfo => "vm01";
-   
+
  vm share_folder => "vm01", add => { sharename => "/path/to/share" };
-   
+
  vm share_folder => "vm01", remove => "sharename";
 
 For VirtualBox memory declaration is always in megabyte.
@@ -70,11 +68,10 @@ For VirtualBox memory declaration is always in megabyte.
 
 package Rex::Virtualization::VBox;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.2'; # VERSION
+our $VERSION = '1.14.2'; # VERSION
 
 use Rex::Virtualization::Base;
 use base qw(Rex::Virtualization::Base);
